WebSource

Struct WebSource 

pub struct WebSource { /* private fields */ }
Web content source that fetches JavaScript, source maps, and WASM from URLs.

URLs ending in .wasm are treated as binary and have strings extracted. URLs ending in .map are treated as source maps and have sourcesContent entries split into individual chunks. Everything else is treated as JavaScript text.

Implementations

Source

impl WebSource

pub fn new(urls: Vec<String>) -> Self

Create a web source from a list of URLs to scan.

Examples
use keyhog_sources::WebSource;
use keyhog_core::Source;

let source = WebSource::new(vec!["https://example.com/app.js".into()]);
assert_eq!(source.name(), "web");
pub fn from_url(url: &str) -> Self

Create a web source from a single URL.

Examples
use keyhog_sources::WebSource;
use keyhog_core::Source;

let source = WebSource::from_url("https://example.com/app.js");
assert_eq!(source.name(), "web");