pub struct WebSource { /* private fields */ }Expand description
Web content source that fetches JavaScript, source maps, and WASM from URLs.
URLs ending in .wasm are treated as binary and have strings extracted.
URLs ending in .map are treated as source maps and have sourcesContent
entries split into individual chunks. Everything else is treated as
JavaScript text.
Implementations